@@ -1,7 +1,6 @@
 
 from datetime import datetime
 
-from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models.base import ModelBase
 from django.template.defaultfilters import slugify, truncatewords_html
@@ -11,6 +10,9 @@ from mezzanine.core.managers import DisplayableManager, KeywordManager
 from mezzanine import settings as blog_settings
 
 
+class HtmlField(models.TextField):
+    pass
+    
 class Displayable(models.Model):
     """
     Abstract model representing a visible object on the website with common 
@@ -19,15 +21,15 @@ class Displayable(models.Model):
     """
 
     title = models.CharField(_("Title"), max_length=100)
-    content = models.TextField(_("Content"))
-    description = models.TextField(_("Description"), blank=True)
+    content = HtmlField(_("Content"))
+    description = HtmlField(_("Description"), blank=True)
     status = models.IntegerField(_("Status"), 
         choices=blog_settings.CONTENT_STATUS_CHOICES, 
         default=blog_settings.CONTENT_STATUS_DRAFT)
     publish_date = models.DateTimeField(_("Published from"), blank=True, 
         help_text=_("With published selected, won't be shown until this time"), 
         default=datetime.now)
-    slug = models.SlugField(max_length=100, editable=False, null=True)
+    slug = models.SlugField(_("URL"), max_length=100, blank=True, null=True)
     keywords = models.ManyToManyField("Keyword", verbose_name=_("Keywords"),
         blank=True)
     _keywords = models.CharField(max_length=500, editable=False)
@@ -61,7 +63,7 @@ class Displayable(models.Model):
                     break
             else:
                 self.description = truncatewords_html(self.content, 100)
-        if self.id is None:
+        if not self.slug:
             self.slug = self.get_slug()
             i = 0
             while True:
