@@ -1,9 +1,12 @@
 
 from django.contrib.admin.views.decorators import staff_member_required
+from django.db.models import get_model
 from django.http import HttpResponse
 from django.shortcuts import render_to_response
 from django.template import RequestContext
+from django.utils.translation import ugettext_lazy as _
 
+from mezzanine.core.forms import get_edit_form
 from mezzanine.core.models import Keyword, Displayable
 from mezzanine.settings import SEARCH_MAX_PAGING_LINKS, SEARCH_PER_PAGE
 from mezzanine.utils import paginate
@@ -34,3 +37,18 @@ def search(request, template="search_results.html"):
     context = {"query": query, "results": results}
     return render_to_response(template, context, RequestContext(request))
 
+def edit(request):
+    model = get_model(request.POST["app"], request.POST["model"])
+    obj = model.objects.get(id=request.POST["id"])
+    form = get_edit_form(obj, request.POST["attr"], data=request.POST)
+    perm = obj._meta.app_label + "." + obj._meta.get_change_permission()
+    if not request.user.has_perm(perm):
+        response = _("Permission denied")
+    elif form.is_valid():
+        form.save()
+        response = ""
+    else:
+        response = form.errors.values()[0][0]
+    return HttpResponse(unicode(response))
+edit = staff_member_required(edit)
+
