@@ -64,8 +64,16 @@ MIDDLEWARE_CLASSES = (
     "django.middleware.common.CommonMiddleware",
     "django.middleware.cache.FetchFromCacheMiddleware",
     "mezzanine.core.middleware.MobileTemplate",
+    "mezzanine.core.middleware.AdminLoginInterfaceSelector",
 )
 
+try:
+    from django.middleware.csrf import CsrfViewMiddleware
+except ImportError:
+    pass
+else:
+    MIDDLEWARE_CLASSES += ("django.middleware.csrf.CsrfViewMiddleware",)
+
 # Store these package names here as they may change in the future since at the 
 # moment we are using custom forks of them.
 PACKAGE_NAME_FILEBROWSER = "filebrowser_safe"
