@@ -13,10 +13,6 @@ if "mezzanine.blog" in settings.INSTALLED_APPS:
     urlpatterns += patterns("", 
         ("^%s/" % BLOG_SLUG, include("mezzanine.blog.urls")),
     )
-if "mezzanine.forms" in settings.INSTALLED_APPS:
-    urlpatterns += patterns("", 
-        ("^", include("mezzanine.forms.urls")),
-    )
 if "mezzanine.pages" in settings.INSTALLED_APPS:
     urlpatterns += patterns("", 
         ("^", include("mezzanine.pages.urls")),
